@@ -1,6 +1,6 @@
 ;;; epkg-elpa.el --- Support for Elpa recipes  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2026 Jonas Bernoulli
+;; Copyright (C) 2016-2025 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.epkg@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/epkg
@@ -43,7 +43,7 @@
      ;; Removed by upstream:
      main-file texinfo
      ;; Unused, see `emir-gelpa--import-recipe':
-     doc-files maintainer manual-sync pdf))
+     doc-files maintainer manual-sync))
 
 ;;; GNU Elpa
 
