@@ -1,14 +1,14 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "epkg" "4.1.4"
+(define-package "epkg" "20251108.1325"
   "Browse the Emacsmirror package database."
   '((emacs   "28.1")
     (compat  "30.1")
-    (closql  "2.4")
+    (closql  "2.3")
     (emacsql "4.3")
     (llama   "1.0"))
   :url "https://github.com/emacscollective/epkg"
-  :commit "fc3cba38a416ec4e26a7d8eb7bc5ee910e67aa73"
-  :revdesc "v4.1.4-0-gfc3cba38a416"
+  :commit "a4c8dc4e760ff9d0079e25fa9000b06791ed009b"
+  :revdesc "a4c8dc4e760f"
   :keywords '("tools")
   :authors '(("Jonas Bernoulli" . "emacs.epkg@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.epkg@jonas.bernoulli.dev")))
