@@ -1,17 +1,17 @@
 ;;; epkg.el --- Browse the Emacsmirror package database  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2026 Jonas Bernoulli
+;; Copyright (C) 2016-2025 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.epkg@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/epkg
 ;; Keywords: tools
 
-;; Package-Version: 4.1.4
-;; Package-Revision: v4.1.4-0-gfc3cba38a416
+;; Package-Version: 20251108.1325
+;; Package-Revision: a4c8dc4e760f
 ;; Package-Requires: (
 ;;     (emacs  "28.1")
 ;;     (compat "30.1")
-;;     (closql  "2.4")
+;;     (closql  "2.3")
 ;;     (emacsql "4.3")
 ;;     (llama   "1.0"))
 
@@ -251,14 +251,14 @@ database."
 (defclass epkg-savannah-package (epkg-git-package) () :abstract t)
 
 (defclass epkg-gnu-package (epkg-savannah-package)
-  ((url-format      :initform "https://git.savannah.gnu.org/git/%r.git")
-   (repopage-format :initform "https://git.savannah.gnu.org/cgit/%r.git")
-   (homepage-format :initform "https://savannah.gnu.org/projects/%r")))
+  ((url-format      :initform "https://git.savannah.gnu.org/git/%n.git")
+   (repopage-format :initform "https://git.savannah.gnu.org/cgit/%n.git")
+   (homepage-format :initform "https://savannah.gnu.org/projects/%n")))
 
 (defclass epkg-nongnu-package (epkg-savannah-package)
-  ((url-format      :initform "https://git.savannah.nongnu.org/git/%r.git")
-   (repopage-format :initform "https://git.savannah.nongnu.org/cgit/%r.git")
-   (homepage-format :initform "https://savannah.nongnu.org/projects/%r")))
+  ((url-format      :initform "https://git.savannah.nongnu.org/git/%n.git")
+   (repopage-format :initform "https://git.savannah.nongnu.org/cgit/%n.git")
+   (homepage-format :initform "https://savannah.nongnu.org/projects/%n")))
 
 (defclass epkg-subtree-package (epkg-git-package) ())
 
@@ -268,13 +268,13 @@ database."
    (homepage-format :initform "https://emacswiki.org/emacs/download/%n.el")))
 
 (defclass epkg-nongnu-elpa-package (epkg-git-package)
-  ((url-format      :initform "https://https.git.savannah.gnu.org/git/elpa/nongnu.git")
-   (repopage-format :initform "https://cgit.git.savannah.gnu.org/cgit/elpa/nongnu.git/?h=elpa/%n")
+  ((url-format      :initform "https://git.savannah.gnu.org/git/emacs/nongnu.git")
+   (repopage-format :initform "https://git.savannah.gnu.org/cgit/emacs/nongnu.git/log/?h=elpa/%n")
    (homepage-format :initform "https://elpa.nongnu.org/nongnu/%n.html")))
 
 (defclass epkg-gnu-elpa-package (epkg-git-package)
-  ((url-format      :initform "https://https.git.savannah.gnu.org/git/elpa/gnu.git")
-   (repopage-format :initform "https://cgit.git.savannah.gnu.org/cgit/elpa/gnu.git/?h=externals/%n")
+  ((url-format      :initform "https://git.savannah.gnu.org/git/emacs/elpa.git")
+   (repopage-format :initform "https://git.savannah.gnu.org/cgit/emacs/elpa.git/log/?h=externals/%n")
    (homepage-format :initform "https://elpa.gnu.org/packages/%n.html")))
 
 (defclass epkg-hg-package (epkg-gitish-package) ())
